Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1225)

Unified Diff: tools/perf/page_sets/login_helpers/mobile_facebook_login.py

Issue 1748883005: Add mobile version of v8.infinite_scroll benchmark. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: add missing hash file Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/perf/page_sets/login_helpers/login_utils.py ('k') | tools/perf/page_sets/mobile_facebook_page.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/perf/page_sets/login_helpers/mobile_facebook_login.py
diff --git a/tools/perf/page_sets/login_helpers/google_login.py b/tools/perf/page_sets/login_helpers/mobile_facebook_login.py
similarity index 52%
copy from tools/perf/page_sets/login_helpers/google_login.py
copy to tools/perf/page_sets/login_helpers/mobile_facebook_login.py
index a59b2c669a6275e4d19556bf7da215eb796fbde9..d8d20734700ed43f745cc9418acc8b5200eb54d0 100644
--- a/tools/perf/page_sets/login_helpers/google_login.py
+++ b/tools/perf/page_sets/login_helpers/mobile_facebook_login.py
@@ -4,11 +4,12 @@
from page_sets.login_helpers import login_utils
-def LoginGoogleAccount(action_runner, credential,
- credentials_path=login_utils.DEFAULT_CREDENTIAL_PATH):
- """Logs in into Google account.
+def LoginAccount(
+ action_runner, credential,
+ credentials_path=login_utils.DEFAULT_CREDENTIAL_PATH):
+ """Logs in into mobile Facebook account.
- This function navigates the tab into Google's login page and logs in a user
+ This function navigates the tab into Facebook's login page and logs in a user
using credentials in |credential| part of the |credentials_path| file.
Args:
@@ -25,11 +26,10 @@ def LoginGoogleAccount(action_runner, credential,
credential, credentials_path=credentials_path)
action_runner.Navigate(
- 'https://accounts.google.com/ServiceLogin?continue='
- 'https%3A%2F%2Faccounts.google.com%2FManageAccount')
- login_utils.InputForm(action_runner, account_name, input_id='Email',
- form_id='gaia_firstform')
- action_runner.ClickElement(selector='#gaia_firstform #next')
- login_utils.InputForm(action_runner, password, input_id='Passwd')
- action_runner.ClickElement(selector='#signIn')
- action_runner.WaitForElement(text='My Account')
+ 'https://m.facebook.com/login?continue=https%3A%2F%2Fm.facebook.com')
+ login_utils.InputWithSelector(action_runner, account_name, '[name=email]')
+ login_utils.InputWithSelector(action_runner, password, '[name=pass]')
+ action_runner.ClickElement(selector='[name=login]')
+ action_runner.WaitForElement(text='OK')
+ action_runner.ClickElement(text='OK')
+ action_runner.WaitForNavigate()
« no previous file with comments | « tools/perf/page_sets/login_helpers/login_utils.py ('k') | tools/perf/page_sets/mobile_facebook_page.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698